# -*- ruby -*-
# encoding: utf-8
# vim: set nosta noet ts=4 sw=4:

require_relative '../../../helpers'

require 'tmpdir'
require 'strelka/cms'
require 'strelka/cms/pagefilter'


#####################################################################
###	C O N T E X T S
#####################################################################

describe Strelka::CMS::PageFilter, 'AutoIndex' do

	SIMPLE_TEST_SOURCE = (<<-END_PAGE_SOURCE).gsub( /^\t{2}/, '' ).freeze
		<?autoindex /blog/*.page ?>
	END_PAGE_SOURCE

	before( :all ) do
		# Need to load this before fakefs hides the filesystem
		Inversion::Template::Tag.load_all
	end


	around( :each ) do |example|
		Dir.mktmpdir( "autoindex_spec" ) do |dirname|
			@tmpdir = dirname
			example.call
		end
	end



	it "is ignored when used from a page that isn't part of a catalog" do
		filter = described_class.create( 'autoindex' )

		page = Strelka::CMS::Page.parse( SIMPLE_TEST_SOURCE )
		output = filter.process( SIMPLE_TEST_SOURCE, page )

		expect( output ).to match( /<!-- autoindex skipped/i )
	end


	it "renders an index of the matched files in the page's catalog" do
		pending "Database rewrite"
		FileUtils.mkdir_p( "#@tmpdir/content/blog" )
		FileUtils.mkdir_p( "#@tmpdir/templates/autoindex" )

		FileUtils.touch( "#@tmpdir/content/blog/post1.page" )
		FileUtils.touch( "#@tmpdir/content/blog/post2.page" )
		FileUtils.touch( "#@tmpdir/content/blog/post3.page" )

		File.open( "#@tmpdir/content/test.page", 'w' ) do |fh|
			fh.print( SIMPLE_TEST_SOURCE )
		end

		File.open( "#@tmpdir/templates/autoindex/default.tmpl", 'w' ) do |fh|
			fh.puts "<?for page in pages ?>"
			fh.puts "-<?call page.relative_html_path ?>-"
			fh.puts "<?end for ?>"
		end

		Inversion::Template.template_paths.replace( ["#@tmpdir/templates"] )

		catalog = Strelka::CMS::PageCatalog.new( "#@tmpdir/content", '**/*.page' )
		page = catalog.find {|page| page.relative_path.to_s == 'test.page' } or
			raise "didn't find test.page in catalog %p" % [ catalog ]

		filter = described_class.create( 'autoindex' )
		output = filter.process( SIMPLE_TEST_SOURCE, page )

		expect( output ).to match( /post1\.html/ )
		expect( output ).to match( /post2\.html/ )
		expect( output ).to match( /post3\.html/ )
	end



end

